@@ -1,4 +1,4 @@
-from typing import Callable
+from typing import Callable, List
 
 from tabdeal.client import TabdealWebsocketClientThread
 
@@ -25,6 +25,18 @@ class SpotWebsocketClient:
             callback=callback,
         )
 
+    def multiple_market_order_book(
+        self, symbols: List[str], id: int, callback: Callable
+    ):
+        return self.subscribe(
+            payload={
+                "method": "SUBSCRIBE",
+                "id": id,
+                "params": [f"{symbol}@depth@2000ms" for symbol in symbols],
+            },
+            callback=callback,
+        )
+
     def user_data(self, listen_key: str, callback):
         return self.subscribe(callback=callback, stream=listen_key)
 
